package cmd

import (
	"os"

	"github.com/evil7/hostsync/core"
	"github.com/evil7/hostsync/utils"
	"github.com/spf13/cobra"
)

// enableCmd 启用命令
var enableCmd = &cobra.Command{
	Use:   "enable <blockName>",
	Short: "启用指定块",
	Long: `启用指定的配置块，使其中的所有域名记录生效。

示例:
  hostsync enable github      # 启用 github 块`,
	Args: cobra.ExactArgs(1),
	Run:  runEnable,
}

func runEnable(cmd *cobra.Command, args []string) {
	utils.CheckAdmin()

	blockName := args[0]
	if !utils.ValidateBlockName(blockName) {
		utils.LogError("无效的块名称: %s", blockName)
		utils.LogInfo("块名称只能包含字母、数字、下划线和连字符")
		os.Exit(1)
	}

	hm := core.NewHostsManager()
	if err := hm.Load(); err != nil {
		utils.LogError("加载hosts文件失败: %v", err)
		os.Exit(1)
	}

	if err := hm.EnableBlock(blockName); err != nil {
		utils.LogError("启用块失败: %v", err)
		os.Exit(1)
	}

	utils.LogSuccess("已启用块: %s", blockName)
}
